from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.listings_provider_info import ListingsProviderInfo
    from ..models.tuner_host_info import TunerHostInfo


T = TypeVar("T", bound="LiveTvOptions")


@_attrs_define
class LiveTvOptions:
    """
    Attributes:
        guide_days (Union[Unset, None, int]):
        recording_path (Union[Unset, None, str]):
        movie_recording_path (Union[Unset, None, str]):
        series_recording_path (Union[Unset, None, str]):
        enable_recording_subfolders (Union[Unset, bool]):
        enable_original_audio_with_encoded_recordings (Union[Unset, bool]):
        tuner_hosts (Union[Unset, None, List['TunerHostInfo']]):
        listing_providers (Union[Unset, None, List['ListingsProviderInfo']]):
        pre_padding_seconds (Union[Unset, int]):
        post_padding_seconds (Union[Unset, int]):
        media_locations_created (Union[Unset, None, List[str]]):
        recording_post_processor (Union[Unset, None, str]):
        recording_post_processor_arguments (Union[Unset, None, str]):
    """

    guide_days: Union[Unset, None, int] = UNSET
    recording_path: Union[Unset, None, str] = UNSET
    movie_recording_path: Union[Unset, None, str] = UNSET
    series_recording_path: Union[Unset, None, str] = UNSET
    enable_recording_subfolders: Union[Unset, bool] = UNSET
    enable_original_audio_with_encoded_recordings: Union[Unset, bool] = UNSET
    tuner_hosts: Union[Unset, None, List["TunerHostInfo"]] = UNSET
    listing_providers: Union[Unset, None, List["ListingsProviderInfo"]] = UNSET
    pre_padding_seconds: Union[Unset, int] = UNSET
    post_padding_seconds: Union[Unset, int] = UNSET
    media_locations_created: Union[Unset, None, List[str]] = UNSET
    recording_post_processor: Union[Unset, None, str] = UNSET
    recording_post_processor_arguments: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        guide_days = self.guide_days
        recording_path = self.recording_path
        movie_recording_path = self.movie_recording_path
        series_recording_path = self.series_recording_path
        enable_recording_subfolders = self.enable_recording_subfolders
        enable_original_audio_with_encoded_recordings = self.enable_original_audio_with_encoded_recordings
        tuner_hosts: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.tuner_hosts, Unset):
            if self.tuner_hosts is None:
                tuner_hosts = None
            else:
                tuner_hosts = []
                for tuner_hosts_item_data in self.tuner_hosts:
                    tuner_hosts_item = tuner_hosts_item_data.to_dict()

                    tuner_hosts.append(tuner_hosts_item)

        listing_providers: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.listing_providers, Unset):
            if self.listing_providers is None:
                listing_providers = None
            else:
                listing_providers = []
                for listing_providers_item_data in self.listing_providers:
                    listing_providers_item = listing_providers_item_data.to_dict()

                    listing_providers.append(listing_providers_item)

        pre_padding_seconds = self.pre_padding_seconds
        post_padding_seconds = self.post_padding_seconds
        media_locations_created: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.media_locations_created, Unset):
            if self.media_locations_created is None:
                media_locations_created = None
            else:
                media_locations_created = self.media_locations_created

        recording_post_processor = self.recording_post_processor
        recording_post_processor_arguments = self.recording_post_processor_arguments

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if guide_days is not UNSET:
            field_dict["GuideDays"] = guide_days
        if recording_path is not UNSET:
            field_dict["RecordingPath"] = recording_path
        if movie_recording_path is not UNSET:
            field_dict["MovieRecordingPath"] = movie_recording_path
        if series_recording_path is not UNSET:
            field_dict["SeriesRecordingPath"] = series_recording_path
        if enable_recording_subfolders is not UNSET:
            field_dict["EnableRecordingSubfolders"] = enable_recording_subfolders
        if enable_original_audio_with_encoded_recordings is not UNSET:
            field_dict["EnableOriginalAudioWithEncodedRecordings"] = enable_original_audio_with_encoded_recordings
        if tuner_hosts is not UNSET:
            field_dict["TunerHosts"] = tuner_hosts
        if listing_providers is not UNSET:
            field_dict["ListingProviders"] = listing_providers
        if pre_padding_seconds is not UNSET:
            field_dict["PrePaddingSeconds"] = pre_padding_seconds
        if post_padding_seconds is not UNSET:
            field_dict["PostPaddingSeconds"] = post_padding_seconds
        if media_locations_created is not UNSET:
            field_dict["MediaLocationsCreated"] = media_locations_created
        if recording_post_processor is not UNSET:
            field_dict["RecordingPostProcessor"] = recording_post_processor
        if recording_post_processor_arguments is not UNSET:
            field_dict["RecordingPostProcessorArguments"] = recording_post_processor_arguments

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.listings_provider_info import ListingsProviderInfo
        from ..models.tuner_host_info import TunerHostInfo

        d = src_dict.copy()
        guide_days = d.pop("GuideDays", UNSET)

        recording_path = d.pop("RecordingPath", UNSET)

        movie_recording_path = d.pop("MovieRecordingPath", UNSET)

        series_recording_path = d.pop("SeriesRecordingPath", UNSET)

        enable_recording_subfolders = d.pop("EnableRecordingSubfolders", UNSET)

        enable_original_audio_with_encoded_recordings = d.pop("EnableOriginalAudioWithEncodedRecordings", UNSET)

        tuner_hosts = []
        _tuner_hosts = d.pop("TunerHosts", UNSET)
        for tuner_hosts_item_data in _tuner_hosts or []:
            tuner_hosts_item = TunerHostInfo.from_dict(tuner_hosts_item_data)

            tuner_hosts.append(tuner_hosts_item)

        listing_providers = []
        _listing_providers = d.pop("ListingProviders", UNSET)
        for listing_providers_item_data in _listing_providers or []:
            listing_providers_item = ListingsProviderInfo.from_dict(listing_providers_item_data)

            listing_providers.append(listing_providers_item)

        pre_padding_seconds = d.pop("PrePaddingSeconds", UNSET)

        post_padding_seconds = d.pop("PostPaddingSeconds", UNSET)

        media_locations_created = cast(List[str], d.pop("MediaLocationsCreated", UNSET))

        recording_post_processor = d.pop("RecordingPostProcessor", UNSET)

        recording_post_processor_arguments = d.pop("RecordingPostProcessorArguments", UNSET)

        live_tv_options = cls(
            guide_days=guide_days,
            recording_path=recording_path,
            movie_recording_path=movie_recording_path,
            series_recording_path=series_recording_path,
            enable_recording_subfolders=enable_recording_subfolders,
            enable_original_audio_with_encoded_recordings=enable_original_audio_with_encoded_recordings,
            tuner_hosts=tuner_hosts,
            listing_providers=listing_providers,
            pre_padding_seconds=pre_padding_seconds,
            post_padding_seconds=post_padding_seconds,
            media_locations_created=media_locations_created,
            recording_post_processor=recording_post_processor,
            recording_post_processor_arguments=recording_post_processor_arguments,
        )

        return live_tv_options



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.group_update_type import GroupUpdateType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ObjectGroupUpdate")


@_attrs_define
class ObjectGroupUpdate:
    """Class GroupUpdate.

    Attributes:
        group_id (Union[Unset, str]): Gets the group identifier.
        type (Union[Unset, GroupUpdateType]): Enum GroupUpdateType.
        data (Union[Unset, Any]): Gets the update data.
    """

    group_id: Union[Unset, str] = UNSET
    type: Union[Unset, GroupUpdateType] = UNSET
    data: Union[Unset, Any] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        group_id = self.group_id
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        data = self.data

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if group_id is not UNSET:
            field_dict["GroupId"] = group_id
        if type is not UNSET:
            field_dict["Type"] = type
        if data is not UNSET:
            field_dict["Data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        group_id = d.pop("GroupId", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, GroupUpdateType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = GroupUpdateType(_type)

        data = d.pop("Data", UNSET)

        object_group_update = cls(
            group_id=group_id,
            type=type,
            data=data,
        )

        return object_group_update



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="IPlugin")


@_attrs_define
class IPlugin:
    """Defines the MediaBrowser.Common.Plugins.IPlugin.

    Attributes:
        name (Union[Unset, None, str]): Gets the name of the plugin.
        description (Union[Unset, None, str]): Gets the Description.
        id (Union[Unset, str]): Gets the unique id.
        version (Union[Unset, None, str]): Gets the plugin version.
        assembly_file_path (Union[Unset, None, str]): Gets the path to the assembly file.
        can_uninstall (Union[Unset, bool]): Gets a value indicating whether the plugin can be uninstalled.
        data_folder_path (Union[Unset, None, str]): Gets the full path to the data folder, where the plugin can store
            any miscellaneous files needed.
    """

    name: Union[Unset, None, str] = UNSET
    description: Union[Unset, None, str] = UNSET
    id: Union[Unset, str] = UNSET
    version: Union[Unset, None, str] = UNSET
    assembly_file_path: Union[Unset, None, str] = UNSET
    can_uninstall: Union[Unset, bool] = UNSET
    data_folder_path: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        description = self.description
        id = self.id
        version = self.version
        assembly_file_path = self.assembly_file_path
        can_uninstall = self.can_uninstall
        data_folder_path = self.data_folder_path

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if description is not UNSET:
            field_dict["Description"] = description
        if id is not UNSET:
            field_dict["Id"] = id
        if version is not UNSET:
            field_dict["Version"] = version
        if assembly_file_path is not UNSET:
            field_dict["AssemblyFilePath"] = assembly_file_path
        if can_uninstall is not UNSET:
            field_dict["CanUninstall"] = can_uninstall
        if data_folder_path is not UNSET:
            field_dict["DataFolderPath"] = data_folder_path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        description = d.pop("Description", UNSET)

        id = d.pop("Id", UNSET)

        version = d.pop("Version", UNSET)

        assembly_file_path = d.pop("AssemblyFilePath", UNSET)

        can_uninstall = d.pop("CanUninstall", UNSET)

        data_folder_path = d.pop("DataFolderPath", UNSET)

        i_plugin = cls(
            name=name,
            description=description,
            id=id,
            version=version,
            assembly_file_path=assembly_file_path,
            can_uninstall=can_uninstall,
            data_folder_path=data_folder_path,
        )

        return i_plugin



from enum import Enum


class BaseItemKind(str, Enum):
    AGGREGATEFOLDER = "AggregateFolder"
    AUDIO = "Audio"
    AUDIOBOOK = "AudioBook"
    BASEPLUGINFOLDER = "BasePluginFolder"
    BOOK = "Book"
    BOXSET = "BoxSet"
    CHANNEL = "Channel"
    CHANNELFOLDERITEM = "ChannelFolderItem"
    COLLECTIONFOLDER = "CollectionFolder"
    EPISODE = "Episode"
    FOLDER = "Folder"
    GENRE = "Genre"
    LIVETVCHANNEL = "LiveTvChannel"
    LIVETVPROGRAM = "LiveTvProgram"
    MANUALPLAYLISTSFOLDER = "ManualPlaylistsFolder"
    MOVIE = "Movie"
    MUSICALBUM = "MusicAlbum"
    MUSICARTIST = "MusicArtist"
    MUSICGENRE = "MusicGenre"
    MUSICVIDEO = "MusicVideo"
    PERSON = "Person"
    PHOTO = "Photo"
    PHOTOALBUM = "PhotoAlbum"
    PLAYLIST = "Playlist"
    PLAYLISTSFOLDER = "PlaylistsFolder"
    PROGRAM = "Program"
    RECORDING = "Recording"
    SEASON = "Season"
    SERIES = "Series"
    STUDIO = "Studio"
    TRAILER = "Trailer"
    TVCHANNEL = "TvChannel"
    TVPROGRAM = "TvProgram"
    USERROOTFOLDER = "UserRootFolder"
    USERVIEW = "UserView"
    VIDEO = "Video"
    YEAR = "Year"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_item_dto_query_result import BaseItemDtoQueryResult
from ...models.base_item_kind import BaseItemKind
from ...models.image_type import ImageType
from ...models.item_fields import ItemFields
from ...models.item_filter import ItemFilter
from ...models.location_type import LocationType
from ...models.series_status import SeriesStatus
from ...models.sort_order import SortOrder
from ...models.video_type import VideoType
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    user_id: Union[Unset, None, str] = UNSET,
    max_official_rating: Union[Unset, None, str] = UNSET,
    has_theme_song: Union[Unset, None, bool] = UNSET,
    has_theme_video: Union[Unset, None, bool] = UNSET,
    has_subtitles: Union[Unset, None, bool] = UNSET,
    has_special_feature: Union[Unset, None, bool] = UNSET,
    has_trailer: Union[Unset, None, bool] = UNSET,
    adjacent_to: Union[Unset, None, str] = UNSET,
    parent_index_number: Union[Unset, None, int] = UNSET,
    has_parental_rating: Union[Unset, None, bool] = UNSET,
    is_hd: Union[Unset, None, bool] = UNSET,
    is_4k: Union[Unset, None, bool] = UNSET,
    location_types: Union[Unset, None, List[LocationType]] = UNSET,
    exclude_location_types: Union[Unset, None, List[LocationType]] = UNSET,
    is_missing: Union[Unset, None, bool] = UNSET,
    is_unaired: Union[Unset, None, bool] = UNSET,
    min_community_rating: Union[Unset, None, float] = UNSET,
    min_critic_rating: Union[Unset, None, float] = UNSET,
    min_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved_for_user: Union[Unset, None, datetime.datetime] = UNSET,
    max_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_overview: Union[Unset, None, bool] = UNSET,
    has_imdb_id: Union[Unset, None, bool] = UNSET,
    has_tmdb_id: Union[Unset, None, bool] = UNSET,
    has_tvdb_id: Union[Unset, None, bool] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    exclude_item_ids: Union[Unset, None, List[str]] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    recursive: Union[Unset, None, bool] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    image_types: Union[Unset, None, List[ImageType]] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    is_played: Union[Unset, None, bool] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    artists: Union[Unset, None, List[str]] = UNSET,
    exclude_artist_ids: Union[Unset, None, List[str]] = UNSET,
    artist_ids: Union[Unset, None, List[str]] = UNSET,
    album_artist_ids: Union[Unset, None, List[str]] = UNSET,
    contributing_artist_ids: Union[Unset, None, List[str]] = UNSET,
    albums: Union[Unset, None, List[str]] = UNSET,
    album_ids: Union[Unset, None, List[str]] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    video_types: Union[Unset, None, List[VideoType]] = UNSET,
    min_official_rating: Union[Unset, None, str] = UNSET,
    is_locked: Union[Unset, None, bool] = UNSET,
    is_place_holder: Union[Unset, None, bool] = UNSET,
    has_official_rating: Union[Unset, None, bool] = UNSET,
    collapse_box_set_items: Union[Unset, None, bool] = UNSET,
    min_width: Union[Unset, None, int] = UNSET,
    min_height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    is_3d: Union[Unset, None, bool] = UNSET,
    series_status: Union[Unset, None, List[SeriesStatus]] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
    enable_images: Union[Unset, None, bool] = True,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["userId"] = user_id

    params["maxOfficialRating"] = max_official_rating

    params["hasThemeSong"] = has_theme_song

    params["hasThemeVideo"] = has_theme_video

    params["hasSubtitles"] = has_subtitles

    params["hasSpecialFeature"] = has_special_feature

    params["hasTrailer"] = has_trailer

    params["adjacentTo"] = adjacent_to

    params["parentIndexNumber"] = parent_index_number

    params["hasParentalRating"] = has_parental_rating

    params["isHd"] = is_hd

    params["is4K"] = is_4k

    json_location_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(location_types, Unset):
        if location_types is None:
            json_location_types = None
        else:
            json_location_types = []
            for location_types_item_data in location_types:
                location_types_item = location_types_item_data.value

                json_location_types.append(location_types_item)

    params["locationTypes"] = json_location_types

    json_exclude_location_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_location_types, Unset):
        if exclude_location_types is None:
            json_exclude_location_types = None
        else:
            json_exclude_location_types = []
            for exclude_location_types_item_data in exclude_location_types:
                exclude_location_types_item = exclude_location_types_item_data.value

                json_exclude_location_types.append(exclude_location_types_item)

    params["excludeLocationTypes"] = json_exclude_location_types

    params["isMissing"] = is_missing

    params["isUnaired"] = is_unaired

    params["minCommunityRating"] = min_community_rating

    params["minCriticRating"] = min_critic_rating

    json_min_premiere_date: Union[Unset, None, str] = UNSET
    if not isinstance(min_premiere_date, Unset):
        json_min_premiere_date = min_premiere_date.isoformat() if min_premiere_date else None

    params["minPremiereDate"] = json_min_premiere_date

    json_min_date_last_saved: Union[Unset, None, str] = UNSET
    if not isinstance(min_date_last_saved, Unset):
        json_min_date_last_saved = min_date_last_saved.isoformat() if min_date_last_saved else None

    params["minDateLastSaved"] = json_min_date_last_saved

    json_min_date_last_saved_for_user: Union[Unset, None, str] = UNSET
    if not isinstance(min_date_last_saved_for_user, Unset):
        json_min_date_last_saved_for_user = (
            min_date_last_saved_for_user.isoformat() if min_date_last_saved_for_user else None
        )

    params["minDateLastSavedForUser"] = json_min_date_last_saved_for_user

    json_max_premiere_date: Union[Unset, None, str] = UNSET
    if not isinstance(max_premiere_date, Unset):
        json_max_premiere_date = max_premiere_date.isoformat() if max_premiere_date else None

    params["maxPremiereDate"] = json_max_premiere_date

    params["hasOverview"] = has_overview

    params["hasImdbId"] = has_imdb_id

    params["hasTmdbId"] = has_tmdb_id

    params["hasTvdbId"] = has_tvdb_id

    params["isMovie"] = is_movie

    params["isSeries"] = is_series

    params["isNews"] = is_news

    params["isKids"] = is_kids

    params["isSports"] = is_sports

    json_exclude_item_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_item_ids, Unset):
        if exclude_item_ids is None:
            json_exclude_item_ids = None
        else:
            json_exclude_item_ids = exclude_item_ids

    params["excludeItemIds"] = json_exclude_item_ids

    params["startIndex"] = start_index

    params["limit"] = limit

    params["recursive"] = recursive

    params["searchTerm"] = search_term

    json_sort_order: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_order, Unset):
        if sort_order is None:
            json_sort_order = None
        else:
            json_sort_order = []
            for sort_order_item_data in sort_order:
                sort_order_item = sort_order_item_data.value

                json_sort_order.append(sort_order_item)

    params["sortOrder"] = json_sort_order

    params["parentId"] = parent_id

    json_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(fields, Unset):
        if fields is None:
            json_fields = None
        else:
            json_fields = []
            for fields_item_data in fields:
                fields_item = fields_item_data.value

                json_fields.append(fields_item)

    params["fields"] = json_fields

    json_exclude_item_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_item_types, Unset):
        if exclude_item_types is None:
            json_exclude_item_types = None
        else:
            json_exclude_item_types = []
            for exclude_item_types_item_data in exclude_item_types:
                exclude_item_types_item = exclude_item_types_item_data.value

                json_exclude_item_types.append(exclude_item_types_item)

    params["excludeItemTypes"] = json_exclude_item_types

    json_filters: Union[Unset, None, List[str]] = UNSET
    if not isinstance(filters, Unset):
        if filters is None:
            json_filters = None
        else:
            json_filters = []
            for filters_item_data in filters:
                filters_item = filters_item_data.value

                json_filters.append(filters_item)

    params["filters"] = json_filters

    params["isFavorite"] = is_favorite

    json_media_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(media_types, Unset):
        if media_types is None:
            json_media_types = None
        else:
            json_media_types = media_types

    params["mediaTypes"] = json_media_types

    json_image_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(image_types, Unset):
        if image_types is None:
            json_image_types = None
        else:
            json_image_types = []
            for image_types_item_data in image_types:
                image_types_item = image_types_item_data.value

                json_image_types.append(image_types_item)

    params["imageTypes"] = json_image_types

    json_sort_by: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_by, Unset):
        if sort_by is None:
            json_sort_by = None
        else:
            json_sort_by = sort_by

    params["sortBy"] = json_sort_by

    params["isPlayed"] = is_played

    json_genres: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genres, Unset):
        if genres is None:
            json_genres = None
        else:
            json_genres = genres

    params["genres"] = json_genres

    json_official_ratings: Union[Unset, None, List[str]] = UNSET
    if not isinstance(official_ratings, Unset):
        if official_ratings is None:
            json_official_ratings = None
        else:
            json_official_ratings = official_ratings

    params["officialRatings"] = json_official_ratings

    json_tags: Union[Unset, None, List[str]] = UNSET
    if not isinstance(tags, Unset):
        if tags is None:
            json_tags = None
        else:
            json_tags = tags

    params["tags"] = json_tags

    json_years: Union[Unset, None, List[int]] = UNSET
    if not isinstance(years, Unset):
        if years is None:
            json_years = None
        else:
            json_years = years

    params["years"] = json_years

    params["enableUserData"] = enable_user_data

    params["imageTypeLimit"] = image_type_limit

    json_enable_image_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(enable_image_types, Unset):
        if enable_image_types is None:
            json_enable_image_types = None
        else:
            json_enable_image_types = []
            for enable_image_types_item_data in enable_image_types:
                enable_image_types_item = enable_image_types_item_data.value

                json_enable_image_types.append(enable_image_types_item)

    params["enableImageTypes"] = json_enable_image_types

    params["person"] = person

    json_person_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(person_ids, Unset):
        if person_ids is None:
            json_person_ids = None
        else:
            json_person_ids = person_ids

    params["personIds"] = json_person_ids

    json_person_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(person_types, Unset):
        if person_types is None:
            json_person_types = None
        else:
            json_person_types = person_types

    params["personTypes"] = json_person_types

    json_studios: Union[Unset, None, List[str]] = UNSET
    if not isinstance(studios, Unset):
        if studios is None:
            json_studios = None
        else:
            json_studios = studios

    params["studios"] = json_studios

    json_artists: Union[Unset, None, List[str]] = UNSET
    if not isinstance(artists, Unset):
        if artists is None:
            json_artists = None
        else:
            json_artists = artists

    params["artists"] = json_artists

    json_exclude_artist_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_artist_ids, Unset):
        if exclude_artist_ids is None:
            json_exclude_artist_ids = None
        else:
            json_exclude_artist_ids = exclude_artist_ids

    params["excludeArtistIds"] = json_exclude_artist_ids

    json_artist_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(artist_ids, Unset):
        if artist_ids is None:
            json_artist_ids = None
        else:
            json_artist_ids = artist_ids

    params["artistIds"] = json_artist_ids

    json_album_artist_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(album_artist_ids, Unset):
        if album_artist_ids is None:
            json_album_artist_ids = None
        else:
            json_album_artist_ids = album_artist_ids

    params["albumArtistIds"] = json_album_artist_ids

    json_contributing_artist_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(contributing_artist_ids, Unset):
        if contributing_artist_ids is None:
            json_contributing_artist_ids = None
        else:
            json_contributing_artist_ids = contributing_artist_ids

    params["contributingArtistIds"] = json_contributing_artist_ids

    json_albums: Union[Unset, None, List[str]] = UNSET
    if not isinstance(albums, Unset):
        if albums is None:
            json_albums = None
        else:
            json_albums = albums

    params["albums"] = json_albums

    json_album_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(album_ids, Unset):
        if album_ids is None:
            json_album_ids = None
        else:
            json_album_ids = album_ids

    params["albumIds"] = json_album_ids

    json_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(ids, Unset):
        if ids is None:
            json_ids = None
        else:
            json_ids = ids

    params["ids"] = json_ids

    json_video_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(video_types, Unset):
        if video_types is None:
            json_video_types = None
        else:
            json_video_types = []
            for video_types_item_data in video_types:
                video_types_item = video_types_item_data.value

                json_video_types.append(video_types_item)

    params["videoTypes"] = json_video_types

    params["minOfficialRating"] = min_official_rating

    params["isLocked"] = is_locked

    params["isPlaceHolder"] = is_place_holder

    params["hasOfficialRating"] = has_official_rating

    params["collapseBoxSetItems"] = collapse_box_set_items

    params["minWidth"] = min_width

    params["minHeight"] = min_height

    params["maxWidth"] = max_width

    params["maxHeight"] = max_height

    params["is3D"] = is_3d

    json_series_status: Union[Unset, None, List[str]] = UNSET
    if not isinstance(series_status, Unset):
        if series_status is None:
            json_series_status = None
        else:
            json_series_status = []
            for series_status_item_data in series_status:
                series_status_item = series_status_item_data.value

                json_series_status.append(series_status_item)

    params["seriesStatus"] = json_series_status

    params["nameStartsWithOrGreater"] = name_starts_with_or_greater

    params["nameStartsWith"] = name_starts_with

    params["nameLessThan"] = name_less_than

    json_studio_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(studio_ids, Unset):
        if studio_ids is None:
            json_studio_ids = None
        else:
            json_studio_ids = studio_ids

    params["studioIds"] = json_studio_ids

    json_genre_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genre_ids, Unset):
        if genre_ids is None:
            json_genre_ids = None
        else:
            json_genre_ids = genre_ids

    params["genreIds"] = json_genre_ids

    params["enableTotalRecordCount"] = enable_total_record_count

    params["enableImages"] = enable_images

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/Trailers",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = BaseItemDtoQueryResult.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
    max_official_rating: Union[Unset, None, str] = UNSET,
    has_theme_song: Union[Unset, None, bool] = UNSET,
    has_theme_video: Union[Unset, None, bool] = UNSET,
    has_subtitles: Union[Unset, None, bool] = UNSET,
    has_special_feature: Union[Unset, None, bool] = UNSET,
    has_trailer: Union[Unset, None, bool] = UNSET,
    adjacent_to: Union[Unset, None, str] = UNSET,
    parent_index_number: Union[Unset, None, int] = UNSET,
    has_parental_rating: Union[Unset, None, bool] = UNSET,
    is_hd: Union[Unset, None, bool] = UNSET,
    is_4k: Union[Unset, None, bool] = UNSET,
    location_types: Union[Unset, None, List[LocationType]] = UNSET,
    exclude_location_types: Union[Unset, None, List[LocationType]] = UNSET,
    is_missing: Union[Unset, None, bool] = UNSET,
    is_unaired: Union[Unset, None, bool] = UNSET,
    min_community_rating: Union[Unset, None, float] = UNSET,
    min_critic_rating: Union[Unset, None, float] = UNSET,
    min_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved_for_user: Union[Unset, None, datetime.datetime] = UNSET,
    max_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_overview: Union[Unset, None, bool] = UNSET,
    has_imdb_id: Union[Unset, None, bool] = UNSET,
    has_tmdb_id: Union[Unset, None, bool] = UNSET,
    has_tvdb_id: Union[Unset, None, bool] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    exclude_item_ids: Union[Unset, None, List[str]] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    recursive: Union[Unset, None, bool] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    image_types: Union[Unset, None, List[ImageType]] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    is_played: Union[Unset, None, bool] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    artists: Union[Unset, None, List[str]] = UNSET,
    exclude_artist_ids: Union[Unset, None, List[str]] = UNSET,
    artist_ids: Union[Unset, None, List[str]] = UNSET,
    album_artist_ids: Union[Unset, None, List[str]] = UNSET,
    contributing_artist_ids: Union[Unset, None, List[str]] = UNSET,
    albums: Union[Unset, None, List[str]] = UNSET,
    album_ids: Union[Unset, None, List[str]] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    video_types: Union[Unset, None, List[VideoType]] = UNSET,
    min_official_rating: Union[Unset, None, str] = UNSET,
    is_locked: Union[Unset, None, bool] = UNSET,
    is_place_holder: Union[Unset, None, bool] = UNSET,
    has_official_rating: Union[Unset, None, bool] = UNSET,
    collapse_box_set_items: Union[Unset, None, bool] = UNSET,
    min_width: Union[Unset, None, int] = UNSET,
    min_height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    is_3d: Union[Unset, None, bool] = UNSET,
    series_status: Union[Unset, None, List[SeriesStatus]] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
    enable_images: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Finds movies and trailers similar to a given trailer.

    Args:
        user_id (Union[Unset, None, str]):
        max_official_rating (Union[Unset, None, str]):
        has_theme_song (Union[Unset, None, bool]):
        has_theme_video (Union[Unset, None, bool]):
        has_subtitles (Union[Unset, None, bool]):
        has_special_feature (Union[Unset, None, bool]):
        has_trailer (Union[Unset, None, bool]):
        adjacent_to (Union[Unset, None, str]):
        parent_index_number (Union[Unset, None, int]):
        has_parental_rating (Union[Unset, None, bool]):
        is_hd (Union[Unset, None, bool]):
        is_4k (Union[Unset, None, bool]):
        location_types (Union[Unset, None, List[LocationType]]):
        exclude_location_types (Union[Unset, None, List[LocationType]]):
        is_missing (Union[Unset, None, bool]):
        is_unaired (Union[Unset, None, bool]):
        min_community_rating (Union[Unset, None, float]):
        min_critic_rating (Union[Unset, None, float]):
        min_premiere_date (Union[Unset, None, datetime.datetime]):
        min_date_last_saved (Union[Unset, None, datetime.datetime]):
        min_date_last_saved_for_user (Union[Unset, None, datetime.datetime]):
        max_premiere_date (Union[Unset, None, datetime.datetime]):
        has_overview (Union[Unset, None, bool]):
        has_imdb_id (Union[Unset, None, bool]):
        has_tmdb_id (Union[Unset, None, bool]):
        has_tvdb_id (Union[Unset, None, bool]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        exclude_item_ids (Union[Unset, None, List[str]]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        recursive (Union[Unset, None, bool]):
        search_term (Union[Unset, None, str]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        image_types (Union[Unset, None, List[ImageType]]):
        sort_by (Union[Unset, None, List[str]]):
        is_played (Union[Unset, None, bool]):
        genres (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        artists (Union[Unset, None, List[str]]):
        exclude_artist_ids (Union[Unset, None, List[str]]):
        artist_ids (Union[Unset, None, List[str]]):
        album_artist_ids (Union[Unset, None, List[str]]):
        contributing_artist_ids (Union[Unset, None, List[str]]):
        albums (Union[Unset, None, List[str]]):
        album_ids (Union[Unset, None, List[str]]):
        ids (Union[Unset, None, List[str]]):
        video_types (Union[Unset, None, List[VideoType]]):
        min_official_rating (Union[Unset, None, str]):
        is_locked (Union[Unset, None, bool]):
        is_place_holder (Union[Unset, None, bool]):
        has_official_rating (Union[Unset, None, bool]):
        collapse_box_set_items (Union[Unset, None, bool]):
        min_width (Union[Unset, None, int]):
        min_height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        is_3d (Union[Unset, None, bool]):
        series_status (Union[Unset, None, List[SeriesStatus]]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        studio_ids (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.
        enable_images (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        max_official_rating=max_official_rating,
        has_theme_song=has_theme_song,
        has_theme_video=has_theme_video,
        has_subtitles=has_subtitles,
        has_special_feature=has_special_feature,
        has_trailer=has_trailer,
        adjacent_to=adjacent_to,
        parent_index_number=parent_index_number,
        has_parental_rating=has_parental_rating,
        is_hd=is_hd,
        is_4k=is_4k,
        location_types=location_types,
        exclude_location_types=exclude_location_types,
        is_missing=is_missing,
        is_unaired=is_unaired,
        min_community_rating=min_community_rating,
        min_critic_rating=min_critic_rating,
        min_premiere_date=min_premiere_date,
        min_date_last_saved=min_date_last_saved,
        min_date_last_saved_for_user=min_date_last_saved_for_user,
        max_premiere_date=max_premiere_date,
        has_overview=has_overview,
        has_imdb_id=has_imdb_id,
        has_tmdb_id=has_tmdb_id,
        has_tvdb_id=has_tvdb_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        exclude_item_ids=exclude_item_ids,
        start_index=start_index,
        limit=limit,
        recursive=recursive,
        search_term=search_term,
        sort_order=sort_order,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        image_types=image_types,
        sort_by=sort_by,
        is_played=is_played,
        genres=genres,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        artists=artists,
        exclude_artist_ids=exclude_artist_ids,
        artist_ids=artist_ids,
        album_artist_ids=album_artist_ids,
        contributing_artist_ids=contributing_artist_ids,
        albums=albums,
        album_ids=album_ids,
        ids=ids,
        video_types=video_types,
        min_official_rating=min_official_rating,
        is_locked=is_locked,
        is_place_holder=is_place_holder,
        has_official_rating=has_official_rating,
        collapse_box_set_items=collapse_box_set_items,
        min_width=min_width,
        min_height=min_height,
        max_width=max_width,
        max_height=max_height,
        is_3d=is_3d,
        series_status=series_status,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        studio_ids=studio_ids,
        genre_ids=genre_ids,
        enable_total_record_count=enable_total_record_count,
        enable_images=enable_images,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
    max_official_rating: Union[Unset, None, str] = UNSET,
    has_theme_song: Union[Unset, None, bool] = UNSET,
    has_theme_video: Union[Unset, None, bool] = UNSET,
    has_subtitles: Union[Unset, None, bool] = UNSET,
    has_special_feature: Union[Unset, None, bool] = UNSET,
    has_trailer: Union[Unset, None, bool] = UNSET,
    adjacent_to: Union[Unset, None, str] = UNSET,
    parent_index_number: Union[Unset, None, int] = UNSET,
    has_parental_rating: Union[Unset, None, bool] = UNSET,
    is_hd: Union[Unset, None, bool] = UNSET,
    is_4k: Union[Unset, None, bool] = UNSET,
    location_types: Union[Unset, None, List[LocationType]] = UNSET,
    exclude_location_types: Union[Unset, None, List[LocationType]] = UNSET,
    is_missing: Union[Unset, None, bool] = UNSET,
    is_unaired: Union[Unset, None, bool] = UNSET,
    min_community_rating: Union[Unset, None, float] = UNSET,
    min_critic_rating: Union[Unset, None, float] = UNSET,
    min_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved_for_user: Union[Unset, None, datetime.datetime] = UNSET,
    max_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_overview: Union[Unset, None, bool] = UNSET,
    has_imdb_id: Union[Unset, None, bool] = UNSET,
    has_tmdb_id: Union[Unset, None, bool] = UNSET,
    has_tvdb_id: Union[Unset, None, bool] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    exclude_item_ids: Union[Unset, None, List[str]] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    recursive: Union[Unset, None, bool] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    image_types: Union[Unset, None, List[ImageType]] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    is_played: Union[Unset, None, bool] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    artists: Union[Unset, None, List[str]] = UNSET,
    exclude_artist_ids: Union[Unset, None, List[str]] = UNSET,
    artist_ids: Union[Unset, None, List[str]] = UNSET,
    album_artist_ids: Union[Unset, None, List[str]] = UNSET,
    contributing_artist_ids: Union[Unset, None, List[str]] = UNSET,
    albums: Union[Unset, None, List[str]] = UNSET,
    album_ids: Union[Unset, None, List[str]] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    video_types: Union[Unset, None, List[VideoType]] = UNSET,
    min_official_rating: Union[Unset, None, str] = UNSET,
    is_locked: Union[Unset, None, bool] = UNSET,
    is_place_holder: Union[Unset, None, bool] = UNSET,
    has_official_rating: Union[Unset, None, bool] = UNSET,
    collapse_box_set_items: Union[Unset, None, bool] = UNSET,
    min_width: Union[Unset, None, int] = UNSET,
    min_height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    is_3d: Union[Unset, None, bool] = UNSET,
    series_status: Union[Unset, None, List[SeriesStatus]] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
    enable_images: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Finds movies and trailers similar to a given trailer.

    Args:
        user_id (Union[Unset, None, str]):
        max_official_rating (Union[Unset, None, str]):
        has_theme_song (Union[Unset, None, bool]):
        has_theme_video (Union[Unset, None, bool]):
        has_subtitles (Union[Unset, None, bool]):
        has_special_feature (Union[Unset, None, bool]):
        has_trailer (Union[Unset, None, bool]):
        adjacent_to (Union[Unset, None, str]):
        parent_index_number (Union[Unset, None, int]):
        has_parental_rating (Union[Unset, None, bool]):
        is_hd (Union[Unset, None, bool]):
        is_4k (Union[Unset, None, bool]):
        location_types (Union[Unset, None, List[LocationType]]):
        exclude_location_types (Union[Unset, None, List[LocationType]]):
        is_missing (Union[Unset, None, bool]):
        is_unaired (Union[Unset, None, bool]):
        min_community_rating (Union[Unset, None, float]):
        min_critic_rating (Union[Unset, None, float]):
        min_premiere_date (Union[Unset, None, datetime.datetime]):
        min_date_last_saved (Union[Unset, None, datetime.datetime]):
        min_date_last_saved_for_user (Union[Unset, None, datetime.datetime]):
        max_premiere_date (Union[Unset, None, datetime.datetime]):
        has_overview (Union[Unset, None, bool]):
        has_imdb_id (Union[Unset, None, bool]):
        has_tmdb_id (Union[Unset, None, bool]):
        has_tvdb_id (Union[Unset, None, bool]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        exclude_item_ids (Union[Unset, None, List[str]]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        recursive (Union[Unset, None, bool]):
        search_term (Union[Unset, None, str]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        image_types (Union[Unset, None, List[ImageType]]):
        sort_by (Union[Unset, None, List[str]]):
        is_played (Union[Unset, None, bool]):
        genres (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        artists (Union[Unset, None, List[str]]):
        exclude_artist_ids (Union[Unset, None, List[str]]):
        artist_ids (Union[Unset, None, List[str]]):
        album_artist_ids (Union[Unset, None, List[str]]):
        contributing_artist_ids (Union[Unset, None, List[str]]):
        albums (Union[Unset, None, List[str]]):
        album_ids (Union[Unset, None, List[str]]):
        ids (Union[Unset, None, List[str]]):
        video_types (Union[Unset, None, List[VideoType]]):
        min_official_rating (Union[Unset, None, str]):
        is_locked (Union[Unset, None, bool]):
        is_place_holder (Union[Unset, None, bool]):
        has_official_rating (Union[Unset, None, bool]):
        collapse_box_set_items (Union[Unset, None, bool]):
        min_width (Union[Unset, None, int]):
        min_height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        is_3d (Union[Unset, None, bool]):
        series_status (Union[Unset, None, List[SeriesStatus]]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        studio_ids (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.
        enable_images (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return sync_detailed(
        client=client,
        user_id=user_id,
        max_official_rating=max_official_rating,
        has_theme_song=has_theme_song,
        has_theme_video=has_theme_video,
        has_subtitles=has_subtitles,
        has_special_feature=has_special_feature,
        has_trailer=has_trailer,
        adjacent_to=adjacent_to,
        parent_index_number=parent_index_number,
        has_parental_rating=has_parental_rating,
        is_hd=is_hd,
        is_4k=is_4k,
        location_types=location_types,
        exclude_location_types=exclude_location_types,
        is_missing=is_missing,
        is_unaired=is_unaired,
        min_community_rating=min_community_rating,
        min_critic_rating=min_critic_rating,
        min_premiere_date=min_premiere_date,
        min_date_last_saved=min_date_last_saved,
        min_date_last_saved_for_user=min_date_last_saved_for_user,
        max_premiere_date=max_premiere_date,
        has_overview=has_overview,
        has_imdb_id=has_imdb_id,
        has_tmdb_id=has_tmdb_id,
        has_tvdb_id=has_tvdb_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        exclude_item_ids=exclude_item_ids,
        start_index=start_index,
        limit=limit,
        recursive=recursive,
        search_term=search_term,
        sort_order=sort_order,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        image_types=image_types,
        sort_by=sort_by,
        is_played=is_played,
        genres=genres,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        artists=artists,
        exclude_artist_ids=exclude_artist_ids,
        artist_ids=artist_ids,
        album_artist_ids=album_artist_ids,
        contributing_artist_ids=contributing_artist_ids,
        albums=albums,
        album_ids=album_ids,
        ids=ids,
        video_types=video_types,
        min_official_rating=min_official_rating,
        is_locked=is_locked,
        is_place_holder=is_place_holder,
        has_official_rating=has_official_rating,
        collapse_box_set_items=collapse_box_set_items,
        min_width=min_width,
        min_height=min_height,
        max_width=max_width,
        max_height=max_height,
        is_3d=is_3d,
        series_status=series_status,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        studio_ids=studio_ids,
        genre_ids=genre_ids,
        enable_total_record_count=enable_total_record_count,
        enable_images=enable_images,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
    max_official_rating: Union[Unset, None, str] = UNSET,
    has_theme_song: Union[Unset, None, bool] = UNSET,
    has_theme_video: Union[Unset, None, bool] = UNSET,
    has_subtitles: Union[Unset, None, bool] = UNSET,
    has_special_feature: Union[Unset, None, bool] = UNSET,
    has_trailer: Union[Unset, None, bool] = UNSET,
    adjacent_to: Union[Unset, None, str] = UNSET,
    parent_index_number: Union[Unset, None, int] = UNSET,
    has_parental_rating: Union[Unset, None, bool] = UNSET,
    is_hd: Union[Unset, None, bool] = UNSET,
    is_4k: Union[Unset, None, bool] = UNSET,
    location_types: Union[Unset, None, List[LocationType]] = UNSET,
    exclude_location_types: Union[Unset, None, List[LocationType]] = UNSET,
    is_missing: Union[Unset, None, bool] = UNSET,
    is_unaired: Union[Unset, None, bool] = UNSET,
    min_community_rating: Union[Unset, None, float] = UNSET,
    min_critic_rating: Union[Unset, None, float] = UNSET,
    min_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved_for_user: Union[Unset, None, datetime.datetime] = UNSET,
    max_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_overview: Union[Unset, None, bool] = UNSET,
    has_imdb_id: Union[Unset, None, bool] = UNSET,
    has_tmdb_id: Union[Unset, None, bool] = UNSET,
    has_tvdb_id: Union[Unset, None, bool] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    exclude_item_ids: Union[Unset, None, List[str]] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    recursive: Union[Unset, None, bool] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    image_types: Union[Unset, None, List[ImageType]] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    is_played: Union[Unset, None, bool] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    artists: Union[Unset, None, List[str]] = UNSET,
    exclude_artist_ids: Union[Unset, None, List[str]] = UNSET,
    artist_ids: Union[Unset, None, List[str]] = UNSET,
    album_artist_ids: Union[Unset, None, List[str]] = UNSET,
    contributing_artist_ids: Union[Unset, None, List[str]] = UNSET,
    albums: Union[Unset, None, List[str]] = UNSET,
    album_ids: Union[Unset, None, List[str]] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    video_types: Union[Unset, None, List[VideoType]] = UNSET,
    min_official_rating: Union[Unset, None, str] = UNSET,
    is_locked: Union[Unset, None, bool] = UNSET,
    is_place_holder: Union[Unset, None, bool] = UNSET,
    has_official_rating: Union[Unset, None, bool] = UNSET,
    collapse_box_set_items: Union[Unset, None, bool] = UNSET,
    min_width: Union[Unset, None, int] = UNSET,
    min_height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    is_3d: Union[Unset, None, bool] = UNSET,
    series_status: Union[Unset, None, List[SeriesStatus]] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
    enable_images: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Finds movies and trailers similar to a given trailer.

    Args:
        user_id (Union[Unset, None, str]):
        max_official_rating (Union[Unset, None, str]):
        has_theme_song (Union[Unset, None, bool]):
        has_theme_video (Union[Unset, None, bool]):
        has_subtitles (Union[Unset, None, bool]):
        has_special_feature (Union[Unset, None, bool]):
        has_trailer (Union[Unset, None, bool]):
        adjacent_to (Union[Unset, None, str]):
        parent_index_number (Union[Unset, None, int]):
        has_parental_rating (Union[Unset, None, bool]):
        is_hd (Union[Unset, None, bool]):
        is_4k (Union[Unset, None, bool]):
        location_types (Union[Unset, None, List[LocationType]]):
        exclude_location_types (Union[Unset, None, List[LocationType]]):
        is_missing (Union[Unset, None, bool]):
        is_unaired (Union[Unset, None, bool]):
        min_community_rating (Union[Unset, None, float]):
        min_critic_rating (Union[Unset, None, float]):
        min_premiere_date (Union[Unset, None, datetime.datetime]):
        min_date_last_saved (Union[Unset, None, datetime.datetime]):
        min_date_last_saved_for_user (Union[Unset, None, datetime.datetime]):
        max_premiere_date (Union[Unset, None, datetime.datetime]):
        has_overview (Union[Unset, None, bool]):
        has_imdb_id (Union[Unset, None, bool]):
        has_tmdb_id (Union[Unset, None, bool]):
        has_tvdb_id (Union[Unset, None, bool]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        exclude_item_ids (Union[Unset, None, List[str]]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        recursive (Union[Unset, None, bool]):
        search_term (Union[Unset, None, str]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        image_types (Union[Unset, None, List[ImageType]]):
        sort_by (Union[Unset, None, List[str]]):
        is_played (Union[Unset, None, bool]):
        genres (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        artists (Union[Unset, None, List[str]]):
        exclude_artist_ids (Union[Unset, None, List[str]]):
        artist_ids (Union[Unset, None, List[str]]):
        album_artist_ids (Union[Unset, None, List[str]]):
        contributing_artist_ids (Union[Unset, None, List[str]]):
        albums (Union[Unset, None, List[str]]):
        album_ids (Union[Unset, None, List[str]]):
        ids (Union[Unset, None, List[str]]):
        video_types (Union[Unset, None, List[VideoType]]):
        min_official_rating (Union[Unset, None, str]):
        is_locked (Union[Unset, None, bool]):
        is_place_holder (Union[Unset, None, bool]):
        has_official_rating (Union[Unset, None, bool]):
        collapse_box_set_items (Union[Unset, None, bool]):
        min_width (Union[Unset, None, int]):
        min_height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        is_3d (Union[Unset, None, bool]):
        series_status (Union[Unset, None, List[SeriesStatus]]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        studio_ids (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.
        enable_images (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        max_official_rating=max_official_rating,
        has_theme_song=has_theme_song,
        has_theme_video=has_theme_video,
        has_subtitles=has_subtitles,
        has_special_feature=has_special_feature,
        has_trailer=has_trailer,
        adjacent_to=adjacent_to,
        parent_index_number=parent_index_number,
        has_parental_rating=has_parental_rating,
        is_hd=is_hd,
        is_4k=is_4k,
        location_types=location_types,
        exclude_location_types=exclude_location_types,
        is_missing=is_missing,
        is_unaired=is_unaired,
        min_community_rating=min_community_rating,
        min_critic_rating=min_critic_rating,
        min_premiere_date=min_premiere_date,
        min_date_last_saved=min_date_last_saved,
        min_date_last_saved_for_user=min_date_last_saved_for_user,
        max_premiere_date=max_premiere_date,
        has_overview=has_overview,
        has_imdb_id=has_imdb_id,
        has_tmdb_id=has_tmdb_id,
        has_tvdb_id=has_tvdb_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        exclude_item_ids=exclude_item_ids,
        start_index=start_index,
        limit=limit,
        recursive=recursive,
        search_term=search_term,
        sort_order=sort_order,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        image_types=image_types,
        sort_by=sort_by,
        is_played=is_played,
        genres=genres,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        artists=artists,
        exclude_artist_ids=exclude_artist_ids,
        artist_ids=artist_ids,
        album_artist_ids=album_artist_ids,
        contributing_artist_ids=contributing_artist_ids,
        albums=albums,
        album_ids=album_ids,
        ids=ids,
        video_types=video_types,
        min_official_rating=min_official_rating,
        is_locked=is_locked,
        is_place_holder=is_place_holder,
        has_official_rating=has_official_rating,
        collapse_box_set_items=collapse_box_set_items,
        min_width=min_width,
        min_height=min_height,
        max_width=max_width,
        max_height=max_height,
        is_3d=is_3d,
        series_status=series_status,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        studio_ids=studio_ids,
        genre_ids=genre_ids,
        enable_total_record_count=enable_total_record_count,
        enable_images=enable_images,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    user_id: Union[Unset, None, str] = UNSET,
    max_official_rating: Union[Unset, None, str] = UNSET,
    has_theme_song: Union[Unset, None, bool] = UNSET,
    has_theme_video: Union[Unset, None, bool] = UNSET,
    has_subtitles: Union[Unset, None, bool] = UNSET,
    has_special_feature: Union[Unset, None, bool] = UNSET,
    has_trailer: Union[Unset, None, bool] = UNSET,
    adjacent_to: Union[Unset, None, str] = UNSET,
    parent_index_number: Union[Unset, None, int] = UNSET,
    has_parental_rating: Union[Unset, None, bool] = UNSET,
    is_hd: Union[Unset, None, bool] = UNSET,
    is_4k: Union[Unset, None, bool] = UNSET,
    location_types: Union[Unset, None, List[LocationType]] = UNSET,
    exclude_location_types: Union[Unset, None, List[LocationType]] = UNSET,
    is_missing: Union[Unset, None, bool] = UNSET,
    is_unaired: Union[Unset, None, bool] = UNSET,
    min_community_rating: Union[Unset, None, float] = UNSET,
    min_critic_rating: Union[Unset, None, float] = UNSET,
    min_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved: Union[Unset, None, datetime.datetime] = UNSET,
    min_date_last_saved_for_user: Union[Unset, None, datetime.datetime] = UNSET,
    max_premiere_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_overview: Union[Unset, None, bool] = UNSET,
    has_imdb_id: Union[Unset, None, bool] = UNSET,
    has_tmdb_id: Union[Unset, None, bool] = UNSET,
    has_tvdb_id: Union[Unset, None, bool] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    exclude_item_ids: Union[Unset, None, List[str]] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    recursive: Union[Unset, None, bool] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    image_types: Union[Unset, None, List[ImageType]] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    is_played: Union[Unset, None, bool] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    artists: Union[Unset, None, List[str]] = UNSET,
    exclude_artist_ids: Union[Unset, None, List[str]] = UNSET,
    artist_ids: Union[Unset, None, List[str]] = UNSET,
    album_artist_ids: Union[Unset, None, List[str]] = UNSET,
    contributing_artist_ids: Union[Unset, None, List[str]] = UNSET,
    albums: Union[Unset, None, List[str]] = UNSET,
    album_ids: Union[Unset, None, List[str]] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    video_types: Union[Unset, None, List[VideoType]] = UNSET,
    min_official_rating: Union[Unset, None, str] = UNSET,
    is_locked: Union[Unset, None, bool] = UNSET,
    is_place_holder: Union[Unset, None, bool] = UNSET,
    has_official_rating: Union[Unset, None, bool] = UNSET,
    collapse_box_set_items: Union[Unset, None, bool] = UNSET,
    min_width: Union[Unset, None, int] = UNSET,
    min_height: Union[Unset, None, int] = UNSET,
    max_width: Union[Unset, None, int] = UNSET,
    max_height: Union[Unset, None, int] = UNSET,
    is_3d: Union[Unset, None, bool] = UNSET,
    series_status: Union[Unset, None, List[SeriesStatus]] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
    enable_images: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Finds movies and trailers similar to a given trailer.

    Args:
        user_id (Union[Unset, None, str]):
        max_official_rating (Union[Unset, None, str]):
        has_theme_song (Union[Unset, None, bool]):
        has_theme_video (Union[Unset, None, bool]):
        has_subtitles (Union[Unset, None, bool]):
        has_special_feature (Union[Unset, None, bool]):
        has_trailer (Union[Unset, None, bool]):
        adjacent_to (Union[Unset, None, str]):
        parent_index_number (Union[Unset, None, int]):
        has_parental_rating (Union[Unset, None, bool]):
        is_hd (Union[Unset, None, bool]):
        is_4k (Union[Unset, None, bool]):
        location_types (Union[Unset, None, List[LocationType]]):
        exclude_location_types (Union[Unset, None, List[LocationType]]):
        is_missing (Union[Unset, None, bool]):
        is_unaired (Union[Unset, None, bool]):
        min_community_rating (Union[Unset, None, float]):
        min_critic_rating (Union[Unset, None, float]):
        min_premiere_date (Union[Unset, None, datetime.datetime]):
        min_date_last_saved (Union[Unset, None, datetime.datetime]):
        min_date_last_saved_for_user (Union[Unset, None, datetime.datetime]):
        max_premiere_date (Union[Unset, None, datetime.datetime]):
        has_overview (Union[Unset, None, bool]):
        has_imdb_id (Union[Unset, None, bool]):
        has_tmdb_id (Union[Unset, None, bool]):
        has_tvdb_id (Union[Unset, None, bool]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        exclude_item_ids (Union[Unset, None, List[str]]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        recursive (Union[Unset, None, bool]):
        search_term (Union[Unset, None, str]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        image_types (Union[Unset, None, List[ImageType]]):
        sort_by (Union[Unset, None, List[str]]):
        is_played (Union[Unset, None, bool]):
        genres (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        artists (Union[Unset, None, List[str]]):
        exclude_artist_ids (Union[Unset, None, List[str]]):
        artist_ids (Union[Unset, None, List[str]]):
        album_artist_ids (Union[Unset, None, List[str]]):
        contributing_artist_ids (Union[Unset, None, List[str]]):
        albums (Union[Unset, None, List[str]]):
        album_ids (Union[Unset, None, List[str]]):
        ids (Union[Unset, None, List[str]]):
        video_types (Union[Unset, None, List[VideoType]]):
        min_official_rating (Union[Unset, None, str]):
        is_locked (Union[Unset, None, bool]):
        is_place_holder (Union[Unset, None, bool]):
        has_official_rating (Union[Unset, None, bool]):
        collapse_box_set_items (Union[Unset, None, bool]):
        min_width (Union[Unset, None, int]):
        min_height (Union[Unset, None, int]):
        max_width (Union[Unset, None, int]):
        max_height (Union[Unset, None, int]):
        is_3d (Union[Unset, None, bool]):
        series_status (Union[Unset, None, List[SeriesStatus]]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        studio_ids (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.
        enable_images (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return (
        await asyncio_detailed(
            client=client,
            user_id=user_id,
            max_official_rating=max_official_rating,
            has_theme_song=has_theme_song,
            has_theme_video=has_theme_video,
            has_subtitles=has_subtitles,
            has_special_feature=has_special_feature,
            has_trailer=has_trailer,
            adjacent_to=adjacent_to,
            parent_index_number=parent_index_number,
            has_parental_rating=has_parental_rating,
            is_hd=is_hd,
            is_4k=is_4k,
            location_types=location_types,
            exclude_location_types=exclude_location_types,
            is_missing=is_missing,
            is_unaired=is_unaired,
            min_community_rating=min_community_rating,
            min_critic_rating=min_critic_rating,
            min_premiere_date=min_premiere_date,
            min_date_last_saved=min_date_last_saved,
            min_date_last_saved_for_user=min_date_last_saved_for_user,
            max_premiere_date=max_premiere_date,
            has_overview=has_overview,
            has_imdb_id=has_imdb_id,
            has_tmdb_id=has_tmdb_id,
            has_tvdb_id=has_tvdb_id,
            is_movie=is_movie,
            is_series=is_series,
            is_news=is_news,
            is_kids=is_kids,
            is_sports=is_sports,
            exclude_item_ids=exclude_item_ids,
            start_index=start_index,
            limit=limit,
            recursive=recursive,
            search_term=search_term,
            sort_order=sort_order,
            parent_id=parent_id,
            fields=fields,
            exclude_item_types=exclude_item_types,
            filters=filters,
            is_favorite=is_favorite,
            media_types=media_types,
            image_types=image_types,
            sort_by=sort_by,
            is_played=is_played,
            genres=genres,
            official_ratings=official_ratings,
            tags=tags,
            years=years,
            enable_user_data=enable_user_data,
            image_type_limit=image_type_limit,
            enable_image_types=enable_image_types,
            person=person,
            person_ids=person_ids,
            person_types=person_types,
            studios=studios,
            artists=artists,
            exclude_artist_ids=exclude_artist_ids,
            artist_ids=artist_ids,
            album_artist_ids=album_artist_ids,
            contributing_artist_ids=contributing_artist_ids,
            albums=albums,
            album_ids=album_ids,
            ids=ids,
            video_types=video_types,
            min_official_rating=min_official_rating,
            is_locked=is_locked,
            is_place_holder=is_place_holder,
            has_official_rating=has_official_rating,
            collapse_box_set_items=collapse_box_set_items,
            min_width=min_width,
            min_height=min_height,
            max_width=max_width,
            max_height=max_height,
            is_3d=is_3d,
            series_status=series_status,
            name_starts_with_or_greater=name_starts_with_or_greater,
            name_starts_with=name_starts_with,
            name_less_than=name_less_than,
            studio_ids=studio_ids,
            genre_ids=genre_ids,
            enable_total_record_count=enable_total_record_count,
            enable_images=enable_images,
        )
    ).parsed



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.send_command_type import SendCommandType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SendCommand")


@_attrs_define
class SendCommand:
    """Class SendCommand.

    Attributes:
        group_id (Union[Unset, str]): Gets the group identifier.
        playlist_item_id (Union[Unset, str]): Gets the playlist identifier of the playing item.
        when (Union[Unset, datetime.datetime]): Gets or sets the UTC time when to execute the command.
        position_ticks (Union[Unset, None, int]): Gets the position ticks.
        command (Union[Unset, SendCommandType]): Enum SendCommandType.
        emitted_at (Union[Unset, datetime.datetime]): Gets the UTC time when this command has been emitted.
    """

    group_id: Union[Unset, str] = UNSET
    playlist_item_id: Union[Unset, str] = UNSET
    when: Union[Unset, datetime.datetime] = UNSET
    position_ticks: Union[Unset, None, int] = UNSET
    command: Union[Unset, SendCommandType] = UNSET
    emitted_at: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        group_id = self.group_id
        playlist_item_id = self.playlist_item_id
        when: Union[Unset, str] = UNSET
        if not isinstance(self.when, Unset):
            when = self.when.isoformat()

        position_ticks = self.position_ticks
        command: Union[Unset, str] = UNSET
        if not isinstance(self.command, Unset):
            command = self.command.value

        emitted_at: Union[Unset, str] = UNSET
        if not isinstance(self.emitted_at, Unset):
            emitted_at = self.emitted_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if group_id is not UNSET:
            field_dict["GroupId"] = group_id
        if playlist_item_id is not UNSET:
            field_dict["PlaylistItemId"] = playlist_item_id
        if when is not UNSET:
            field_dict["When"] = when
        if position_ticks is not UNSET:
            field_dict["PositionTicks"] = position_ticks
        if command is not UNSET:
            field_dict["Command"] = command
        if emitted_at is not UNSET:
            field_dict["EmittedAt"] = emitted_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        group_id = d.pop("GroupId", UNSET)

        playlist_item_id = d.pop("PlaylistItemId", UNSET)

        _when = d.pop("When", UNSET)
        when: Union[Unset, datetime.datetime]
        if isinstance(_when, Unset):
            when = UNSET
        else:
            when = isoparse(_when)

        position_ticks = d.pop("PositionTicks", UNSET)

        _command = d.pop("Command", UNSET)
        command: Union[Unset, SendCommandType]
        if isinstance(_command, Unset):
            command = UNSET
        else:
            command = SendCommandType(_command)

        _emitted_at = d.pop("EmittedAt", UNSET)
        emitted_at: Union[Unset, datetime.datetime]
        if isinstance(_emitted_at, Unset):
            emitted_at = UNSET
        else:
            emitted_at = isoparse(_emitted_at)

        send_command = cls(
            group_id=group_id,
            playlist_item_id=playlist_item_id,
            when=when,
            position_ticks=position_ticks,
            command=command,
            emitted_at=emitted_at,
        )

        return send_command



from enum import Enum


class SubtitleDeliveryMethod(str, Enum):
    DROP = "Drop"
    EMBED = "Embed"
    ENCODE = "Encode"
    EXTERNAL = "External"
    HLS = "Hls"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="VersionInfo")


@_attrs_define
class VersionInfo:
    """Defines the MediaBrowser.Model.Updates.VersionInfo class.

    Attributes:
        version (Union[Unset, str]): Gets or sets the version.
        version_number (Union[Unset, str]): Gets the version as a System.Version.
        changelog (Union[Unset, None, str]): Gets or sets the changelog for this version.
        target_abi (Union[Unset, None, str]): Gets or sets the ABI that this version was built against.
        source_url (Union[Unset, None, str]): Gets or sets the source URL.
        checksum (Union[Unset, None, str]): Gets or sets a checksum for the binary.
        timestamp (Union[Unset, None, str]): Gets or sets a timestamp of when the binary was built.
        repository_name (Union[Unset, str]): Gets or sets the repository name.
        repository_url (Union[Unset, str]): Gets or sets the repository url.
    """

    version: Union[Unset, str] = UNSET
    version_number: Union[Unset, str] = UNSET
    changelog: Union[Unset, None, str] = UNSET
    target_abi: Union[Unset, None, str] = UNSET
    source_url: Union[Unset, None, str] = UNSET
    checksum: Union[Unset, None, str] = UNSET
    timestamp: Union[Unset, None, str] = UNSET
    repository_name: Union[Unset, str] = UNSET
    repository_url: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        version = self.version
        version_number = self.version_number
        changelog = self.changelog
        target_abi = self.target_abi
        source_url = self.source_url
        checksum = self.checksum
        timestamp = self.timestamp
        repository_name = self.repository_name
        repository_url = self.repository_url

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if version is not UNSET:
            field_dict["version"] = version
        if version_number is not UNSET:
            field_dict["VersionNumber"] = version_number
        if changelog is not UNSET:
            field_dict["changelog"] = changelog
        if target_abi is not UNSET:
            field_dict["targetAbi"] = target_abi
        if source_url is not UNSET:
            field_dict["sourceUrl"] = source_url
        if checksum is not UNSET:
            field_dict["checksum"] = checksum
        if timestamp is not UNSET:
            field_dict["timestamp"] = timestamp
        if repository_name is not UNSET:
            field_dict["repositoryName"] = repository_name
        if repository_url is not UNSET:
            field_dict["repositoryUrl"] = repository_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        version = d.pop("version", UNSET)

        version_number = d.pop("VersionNumber", UNSET)

        changelog = d.pop("changelog", UNSET)

        target_abi = d.pop("targetAbi", UNSET)

        source_url = d.pop("sourceUrl", UNSET)

        checksum = d.pop("checksum", UNSET)

        timestamp = d.pop("timestamp", UNSET)

        repository_name = d.pop("repositoryName", UNSET)

        repository_url = d.pop("repositoryUrl", UNSET)

        version_info = cls(
            version=version,
            version_number=version_number,
            changelog=changelog,
            target_abi=target_abi,
            source_url=source_url,
            checksum=checksum,
            timestamp=timestamp,
            repository_name=repository_name,
            repository_url=repository_url,
        )

        return version_info



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.general_command_type import GeneralCommandType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.general_command_arguments import GeneralCommandArguments


T = TypeVar("T", bound="GeneralCommand")


@_attrs_define
class GeneralCommand:
    """
    Attributes:
        name (Union[Unset, GeneralCommandType]): This exists simply to identify a set of known commands.
        controlling_user_id (Union[Unset, str]):
        arguments (Union[Unset, GeneralCommandArguments]):
    """

    name: Union[Unset, GeneralCommandType] = UNSET
    controlling_user_id: Union[Unset, str] = UNSET
    arguments: Union[Unset, "GeneralCommandArguments"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name: Union[Unset, str] = UNSET
        if not isinstance(self.name, Unset):
            name = self.name.value

        controlling_user_id = self.controlling_user_id
        arguments: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.arguments, Unset):
            arguments = self.arguments.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if controlling_user_id is not UNSET:
            field_dict["ControllingUserId"] = controlling_user_id
        if arguments is not UNSET:
            field_dict["Arguments"] = arguments

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.general_command_arguments import GeneralCommandArguments

        d = src_dict.copy()
        _name = d.pop("Name", UNSET)
        name: Union[Unset, GeneralCommandType]
        if isinstance(_name, Unset):
            name = UNSET
        else:
            name = GeneralCommandType(_name)

        controlling_user_id = d.pop("ControllingUserId", UNSET)

        _arguments = d.pop("Arguments", UNSET)
        arguments: Union[Unset, GeneralCommandArguments]
        if isinstance(_arguments, Unset):
            arguments = UNSET
        else:
            arguments = GeneralCommandArguments.from_dict(_arguments)

        general_command = cls(
            name=name,
            controlling_user_id=controlling_user_id,
            arguments=arguments,
        )

        return general_command



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.playstate_command import PlaystateCommand
from ..types import UNSET, Unset

T = TypeVar("T", bound="PlaystateRequest")


@_attrs_define
class PlaystateRequest:
    """
    Attributes:
        command (Union[Unset, PlaystateCommand]): Enum PlaystateCommand.
        seek_position_ticks (Union[Unset, None, int]):
        controlling_user_id (Union[Unset, None, str]): Gets or sets the controlling user identifier.
    """

    command: Union[Unset, PlaystateCommand] = UNSET
    seek_position_ticks: Union[Unset, None, int] = UNSET
    controlling_user_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        command: Union[Unset, str] = UNSET
        if not isinstance(self.command, Unset):
            command = self.command.value

        seek_position_ticks = self.seek_position_ticks
        controlling_user_id = self.controlling_user_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if command is not UNSET:
            field_dict["Command"] = command
        if seek_position_ticks is not UNSET:
            field_dict["SeekPositionTicks"] = seek_position_ticks
        if controlling_user_id is not UNSET:
            field_dict["ControllingUserId"] = controlling_user_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _command = d.pop("Command", UNSET)
        command: Union[Unset, PlaystateCommand]
        if isinstance(_command, Unset):
            command = UNSET
        else:
            command = PlaystateCommand(_command)

        seek_position_ticks = d.pop("SeekPositionTicks", UNSET)

        controlling_user_id = d.pop("ControllingUserId", UNSET)

        playstate_request = cls(
            command=command,
            seek_position_ticks=seek_position_ticks,
            controlling_user_id=controlling_user_id,
        )

        return playstate_request



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.playback_error_code import PlaybackErrorCode
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_source_info import MediaSourceInfo


T = TypeVar("T", bound="PlaybackInfoResponse")


@_attrs_define
class PlaybackInfoResponse:
    """Class PlaybackInfoResponse.

    Attributes:
        media_sources (Union[Unset, List['MediaSourceInfo']]): Gets or sets the media sources.
        play_session_id (Union[Unset, None, str]): Gets or sets the play session identifier.
        error_code (Union[Unset, None, PlaybackErrorCode]):
    """

    media_sources: Union[Unset, List["MediaSourceInfo"]] = UNSET
    play_session_id: Union[Unset, None, str] = UNSET
    error_code: Union[Unset, None, PlaybackErrorCode] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        media_sources: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.media_sources, Unset):
            media_sources = []
            for media_sources_item_data in self.media_sources:
                media_sources_item = media_sources_item_data.to_dict()

                media_sources.append(media_sources_item)

        play_session_id = self.play_session_id
        error_code: Union[Unset, None, str] = UNSET
        if not isinstance(self.error_code, Unset):
            error_code = self.error_code.value if self.error_code else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if media_sources is not UNSET:
            field_dict["MediaSources"] = media_sources
        if play_session_id is not UNSET:
            field_dict["PlaySessionId"] = play_session_id
        if error_code is not UNSET:
            field_dict["ErrorCode"] = error_code

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_source_info import MediaSourceInfo

        d = src_dict.copy()
        media_sources = []
        _media_sources = d.pop("MediaSources", UNSET)
        for media_sources_item_data in _media_sources or []:
            media_sources_item = MediaSourceInfo.from_dict(media_sources_item_data)

            media_sources.append(media_sources_item)

        play_session_id = d.pop("PlaySessionId", UNSET)

        _error_code = d.pop("ErrorCode", UNSET)
        error_code: Union[Unset, None, PlaybackErrorCode]
        if _error_code is None:
            error_code = None
        elif isinstance(_error_code, Unset):
            error_code = UNSET
        else:
            error_code = PlaybackErrorCode(_error_code)

        playback_info_response = cls(
            media_sources=media_sources,
            play_session_id=play_session_id,
            error_code=error_code,
        )

        return playback_info_response



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="PlaylistCreationResult")


@_attrs_define
class PlaylistCreationResult:
    """
    Attributes:
        id (Union[Unset, str]):
    """

    id: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        playlist_creation_result = cls(
            id=id,
        )

        return playlist_creation_result



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.play_method import PlayMethod
from ..models.repeat_mode import RepeatMode
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.base_item_dto import BaseItemDto
    from ..models.queue_item import QueueItem


T = TypeVar("T", bound="PlaybackProgressInfo")


@_attrs_define
class PlaybackProgressInfo:
    """Class PlaybackProgressInfo.

    Attributes:
        can_seek (Union[Unset, bool]): Gets or sets a value indicating whether this instance can seek.
        item (Union[Unset, None, BaseItemDto]): This is strictly used as a data transfer object from the api layer.
            This holds information about a BaseItem in a format that is convenient for the client.
        item_id (Union[Unset, str]): Gets or sets the item identifier.
        session_id (Union[Unset, None, str]): Gets or sets the session id.
        media_source_id (Union[Unset, None, str]): Gets or sets the media version identifier.
        audio_stream_index (Union[Unset, None, int]): Gets or sets the index of the audio stream.
        subtitle_stream_index (Union[Unset, None, int]): Gets or sets the index of the subtitle stream.
        is_paused (Union[Unset, bool]): Gets or sets a value indicating whether this instance is paused.
        is_muted (Union[Unset, bool]): Gets or sets a value indicating whether this instance is muted.
        position_ticks (Union[Unset, None, int]): Gets or sets the position ticks.
        playback_start_time_ticks (Union[Unset, None, int]):
        volume_level (Union[Unset, None, int]): Gets or sets the volume level.
        brightness (Union[Unset, None, int]):
        aspect_ratio (Union[Unset, None, str]):
        play_method (Union[Unset, PlayMethod]):
        live_stream_id (Union[Unset, None, str]): Gets or sets the live stream identifier.
        play_session_id (Union[Unset, None, str]): Gets or sets the play session identifier.
        repeat_mode (Union[Unset, RepeatMode]):
        now_playing_queue (Union[Unset, None, List['QueueItem']]):
        playlist_item_id (Union[Unset, None, str]):
    """

    can_seek: Union[Unset, bool] = UNSET
    item: Union[Unset, None, "BaseItemDto"] = UNSET
    item_id: Union[Unset, str] = UNSET
    session_id: Union[Unset, None, str] = UNSET
    media_source_id: Union[Unset, None, str] = UNSET
    audio_stream_index: Union[Unset, None, int] = UNSET
    subtitle_stream_index: Union[Unset, None, int] = UNSET
    is_paused: Union[Unset, bool] = UNSET
    is_muted: Union[Unset, bool] = UNSET
    position_ticks: Union[Unset, None, int] = UNSET
    playback_start_time_ticks: Union[Unset, None, int] = UNSET
    volume_level: Union[Unset, None, int] = UNSET
    brightness: Union[Unset, None, int] = UNSET
    aspect_ratio: Union[Unset, None, str] = UNSET
    play_method: Union[Unset, PlayMethod] = UNSET
    live_stream_id: Union[Unset, None, str] = UNSET
    play_session_id: Union[Unset, None, str] = UNSET
    repeat_mode: Union[Unset, RepeatMode] = UNSET
    now_playing_queue: Union[Unset, None, List["QueueItem"]] = UNSET
    playlist_item_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        can_seek = self.can_seek
        item: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.item, Unset):
            item = self.item.to_dict() if self.item else None

        item_id = self.item_id
        session_id = self.session_id
        media_source_id = self.media_source_id
        audio_stream_index = self.audio_stream_index
        subtitle_stream_index = self.subtitle_stream_index
        is_paused = self.is_paused
        is_muted = self.is_muted
        position_ticks = self.position_ticks
        playback_start_time_ticks = self.playback_start_time_ticks
        volume_level = self.volume_level
        brightness = self.brightness
        aspect_ratio = self.aspect_ratio
        play_method: Union[Unset, str] = UNSET
        if not isinstance(self.play_method, Unset):
            play_method = self.play_method.value

        live_stream_id = self.live_stream_id
        play_session_id = self.play_session_id
        repeat_mode: Union[Unset, str] = UNSET
        if not isinstance(self.repeat_mode, Unset):
            repeat_mode = self.repeat_mode.value

        now_playing_queue: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.now_playing_queue, Unset):
            if self.now_playing_queue is None:
                now_playing_queue = None
            else:
                now_playing_queue = []
                for now_playing_queue_item_data in self.now_playing_queue:
                    now_playing_queue_item = now_playing_queue_item_data.to_dict()

                    now_playing_queue.append(now_playing_queue_item)

        playlist_item_id = self.playlist_item_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if can_seek is not UNSET:
            field_dict["CanSeek"] = can_seek
        if item is not UNSET:
            field_dict["Item"] = item
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id
        if session_id is not UNSET:
            field_dict["SessionId"] = session_id
        if media_source_id is not UNSET:
            field_dict["MediaSourceId"] = media_source_id
        if audio_stream_index is not UNSET:
            field_dict["AudioStreamIndex"] = audio_stream_index
        if subtitle_stream_index is not UNSET:
            field_dict["SubtitleStreamIndex"] = subtitle_stream_index
        if is_paused is not UNSET:
            field_dict["IsPaused"] = is_paused
        if is_muted is not UNSET:
            field_dict["IsMuted"] = is_muted
        if position_ticks is not UNSET:
            field_dict["PositionTicks"] = position_ticks
        if playback_start_time_ticks is not UNSET:
            field_dict["PlaybackStartTimeTicks"] = playback_start_time_ticks
        if volume_level is not UNSET:
            field_dict["VolumeLevel"] = volume_level
        if brightness is not UNSET:
            field_dict["Brightness"] = brightness
        if aspect_ratio is not UNSET:
            field_dict["AspectRatio"] = aspect_ratio
        if play_method is not UNSET:
            field_dict["PlayMethod"] = play_method
        if live_stream_id is not UNSET:
            field_dict["LiveStreamId"] = live_stream_id
        if play_session_id is not UNSET:
            field_dict["PlaySessionId"] = play_session_id
        if repeat_mode is not UNSET:
            field_dict["RepeatMode"] = repeat_mode
        if now_playing_queue is not UNSET:
            field_dict["NowPlayingQueue"] = now_playing_queue
        if playlist_item_id is not UNSET:
            field_dict["PlaylistItemId"] = playlist_item_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.base_item_dto import BaseItemDto
        from ..models.queue_item import QueueItem

        d = src_dict.copy()
        can_seek = d.pop("CanSeek", UNSET)

        _item = d.pop("Item", UNSET)
        item: Union[Unset, None, BaseItemDto]
        if _item is None:
            item = None
        elif isinstance(_item, Unset):
            item = UNSET
        else:
            item = BaseItemDto.from_dict(_item)

        item_id = d.pop("ItemId", UNSET)

        session_id = d.pop("SessionId", UNSET)

        media_source_id = d.pop("MediaSourceId", UNSET)

        audio_stream_index = d.pop("AudioStreamIndex", UNSET)

        subtitle_stream_index = d.pop("SubtitleStreamIndex", UNSET)

        is_paused = d.pop("IsPaused", UNSET)

        is_muted = d.pop("IsMuted", UNSET)

        position_ticks = d.pop("PositionTicks", UNSET)

        playback_start_time_ticks = d.pop("PlaybackStartTimeTicks", UNSET)

        volume_level = d.pop("VolumeLevel", UNSET)

        brightness = d.pop("Brightness", UNSET)

        aspect_ratio = d.pop("AspectRatio", UNSET)

        _play_method = d.pop("PlayMethod", UNSET)
        play_method: Union[Unset, PlayMethod]
        if isinstance(_play_method, Unset):
            play_method = UNSET
        else:
            play_method = PlayMethod(_play_method)

        live_stream_id = d.pop("LiveStreamId", UNSET)

        play_session_id = d.pop("PlaySessionId", UNSET)

        _repeat_mode = d.pop("RepeatMode", UNSET)
        repeat_mode: Union[Unset, RepeatMode]
        if isinstance(_repeat_mode, Unset):
            repeat_mode = UNSET
        else:
            repeat_mode = RepeatMode(_repeat_mode)

        now_playing_queue = []
        _now_playing_queue = d.pop("NowPlayingQueue", UNSET)
        for now_playing_queue_item_data in _now_playing_queue or []:
            now_playing_queue_item = QueueItem.from_dict(now_playing_queue_item_data)

            now_playing_queue.append(now_playing_queue_item)

        playlist_item_id = d.pop("PlaylistItemId", UNSET)

        playback_progress_info = cls(
            can_seek=can_seek,
            item=item,
            item_id=item_id,
            session_id=session_id,
            media_source_id=media_source_id,
            audio_stream_index=audio_stream_index,
            subtitle_stream_index=subtitle_stream_index,
            is_paused=is_paused,
            is_muted=is_muted,
            position_ticks=position_ticks,
            playback_start_time_ticks=playback_start_time_ticks,
            volume_level=volume_level,
            brightness=brightness,
            aspect_ratio=aspect_ratio,
            play_method=play_method,
            live_stream_id=live_stream_id,
            play_session_id=play_session_id,
            repeat_mode=repeat_mode,
            now_playing_queue=now_playing_queue,
            playlist_item_id=playlist_item_id,
        )

        return playback_progress_info



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="QueryFiltersLegacy")


@_attrs_define
class QueryFiltersLegacy:
    """
    Attributes:
        genres (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
    """

    genres: Union[Unset, None, List[str]] = UNSET
    tags: Union[Unset, None, List[str]] = UNSET
    official_ratings: Union[Unset, None, List[str]] = UNSET
    years: Union[Unset, None, List[int]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        genres: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.genres, Unset):
            if self.genres is None:
                genres = None
            else:
                genres = self.genres

        tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            if self.tags is None:
                tags = None
            else:
                tags = self.tags

        official_ratings: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.official_ratings, Unset):
            if self.official_ratings is None:
                official_ratings = None
            else:
                official_ratings = self.official_ratings

        years: Union[Unset, None, List[int]] = UNSET
        if not isinstance(self.years, Unset):
            if self.years is None:
                years = None
            else:
                years = self.years

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if genres is not UNSET:
            field_dict["Genres"] = genres
        if tags is not UNSET:
            field_dict["Tags"] = tags
        if official_ratings is not UNSET:
            field_dict["OfficialRatings"] = official_ratings
        if years is not UNSET:
            field_dict["Years"] = years

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        genres = cast(List[str], d.pop("Genres", UNSET))

        tags = cast(List[str], d.pop("Tags", UNSET))

        official_ratings = cast(List[str], d.pop("OfficialRatings", UNSET))

        years = cast(List[int], d.pop("Years", UNSET))

        query_filters_legacy = cls(
            genres=genres,
            tags=tags,
            official_ratings=official_ratings,
            years=years,
        )

        return query_filters_legacy



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_item_dto_query_result import BaseItemDtoQueryResult
from ...models.base_item_kind import BaseItemKind
from ...models.image_type import ImageType
from ...models.item_fields import ItemFields
from ...models.item_filter import ItemFilter
from ...models.sort_order import SortOrder
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    min_community_rating: Union[Unset, None, float] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    enable_images: Union[Unset, None, bool] = True,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["minCommunityRating"] = min_community_rating

    params["startIndex"] = start_index

    params["limit"] = limit

    params["searchTerm"] = search_term

    params["parentId"] = parent_id

    json_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(fields, Unset):
        if fields is None:
            json_fields = None
        else:
            json_fields = []
            for fields_item_data in fields:
                fields_item = fields_item_data.value

                json_fields.append(fields_item)

    params["fields"] = json_fields

    json_exclude_item_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_item_types, Unset):
        if exclude_item_types is None:
            json_exclude_item_types = None
        else:
            json_exclude_item_types = []
            for exclude_item_types_item_data in exclude_item_types:
                exclude_item_types_item = exclude_item_types_item_data.value

                json_exclude_item_types.append(exclude_item_types_item)

    params["excludeItemTypes"] = json_exclude_item_types

    json_include_item_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_item_types, Unset):
        if include_item_types is None:
            json_include_item_types = None
        else:
            json_include_item_types = []
            for include_item_types_item_data in include_item_types:
                include_item_types_item = include_item_types_item_data.value

                json_include_item_types.append(include_item_types_item)

    params["includeItemTypes"] = json_include_item_types

    json_filters: Union[Unset, None, List[str]] = UNSET
    if not isinstance(filters, Unset):
        if filters is None:
            json_filters = None
        else:
            json_filters = []
            for filters_item_data in filters:
                filters_item = filters_item_data.value

                json_filters.append(filters_item)

    params["filters"] = json_filters

    params["isFavorite"] = is_favorite

    json_media_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(media_types, Unset):
        if media_types is None:
            json_media_types = None
        else:
            json_media_types = media_types

    params["mediaTypes"] = json_media_types

    json_genres: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genres, Unset):
        if genres is None:
            json_genres = None
        else:
            json_genres = genres

    params["genres"] = json_genres

    json_genre_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genre_ids, Unset):
        if genre_ids is None:
            json_genre_ids = None
        else:
            json_genre_ids = genre_ids

    params["genreIds"] = json_genre_ids

    json_official_ratings: Union[Unset, None, List[str]] = UNSET
    if not isinstance(official_ratings, Unset):
        if official_ratings is None:
            json_official_ratings = None
        else:
            json_official_ratings = official_ratings

    params["officialRatings"] = json_official_ratings

    json_tags: Union[Unset, None, List[str]] = UNSET
    if not isinstance(tags, Unset):
        if tags is None:
            json_tags = None
        else:
            json_tags = tags

    params["tags"] = json_tags

    json_years: Union[Unset, None, List[int]] = UNSET
    if not isinstance(years, Unset):
        if years is None:
            json_years = None
        else:
            json_years = years

    params["years"] = json_years

    params["enableUserData"] = enable_user_data

    params["imageTypeLimit"] = image_type_limit

    json_enable_image_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(enable_image_types, Unset):
        if enable_image_types is None:
            json_enable_image_types = None
        else:
            json_enable_image_types = []
            for enable_image_types_item_data in enable_image_types:
                enable_image_types_item = enable_image_types_item_data.value

                json_enable_image_types.append(enable_image_types_item)

    params["enableImageTypes"] = json_enable_image_types

    params["person"] = person

    json_person_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(person_ids, Unset):
        if person_ids is None:
            json_person_ids = None
        else:
            json_person_ids = person_ids

    params["personIds"] = json_person_ids

    json_person_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(person_types, Unset):
        if person_types is None:
            json_person_types = None
        else:
            json_person_types = person_types

    params["personTypes"] = json_person_types

    json_studios: Union[Unset, None, List[str]] = UNSET
    if not isinstance(studios, Unset):
        if studios is None:
            json_studios = None
        else:
            json_studios = studios

    params["studios"] = json_studios

    json_studio_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(studio_ids, Unset):
        if studio_ids is None:
            json_studio_ids = None
        else:
            json_studio_ids = studio_ids

    params["studioIds"] = json_studio_ids

    params["userId"] = user_id

    params["nameStartsWithOrGreater"] = name_starts_with_or_greater

    params["nameStartsWith"] = name_starts_with

    params["nameLessThan"] = name_less_than

    json_sort_by: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_by, Unset):
        if sort_by is None:
            json_sort_by = None
        else:
            json_sort_by = sort_by

    params["sortBy"] = json_sort_by

    json_sort_order: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_order, Unset):
        if sort_order is None:
            json_sort_order = None
        else:
            json_sort_order = []
            for sort_order_item_data in sort_order:
                sort_order_item = sort_order_item_data.value

                json_sort_order.append(sort_order_item)

    params["sortOrder"] = json_sort_order

    params["enableImages"] = enable_images

    params["enableTotalRecordCount"] = enable_total_record_count

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/Artists",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = BaseItemDtoQueryResult.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    min_community_rating: Union[Unset, None, float] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    enable_images: Union[Unset, None, bool] = True,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Gets all artists from a given item, folder, or the entire library.

    Args:
        min_community_rating (Union[Unset, None, float]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        search_term (Union[Unset, None, str]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        studio_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        enable_images (Union[Unset, None, bool]):  Default: True.
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        min_community_rating=min_community_rating,
        start_index=start_index,
        limit=limit,
        search_term=search_term,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        include_item_types=include_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        genres=genres,
        genre_ids=genre_ids,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        studio_ids=studio_ids,
        user_id=user_id,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        sort_by=sort_by,
        sort_order=sort_order,
        enable_images=enable_images,
        enable_total_record_count=enable_total_record_count,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    min_community_rating: Union[Unset, None, float] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    enable_images: Union[Unset, None, bool] = True,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Gets all artists from a given item, folder, or the entire library.

    Args:
        min_community_rating (Union[Unset, None, float]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        search_term (Union[Unset, None, str]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        studio_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        enable_images (Union[Unset, None, bool]):  Default: True.
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return sync_detailed(
        client=client,
        min_community_rating=min_community_rating,
        start_index=start_index,
        limit=limit,
        search_term=search_term,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        include_item_types=include_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        genres=genres,
        genre_ids=genre_ids,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        studio_ids=studio_ids,
        user_id=user_id,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        sort_by=sort_by,
        sort_order=sort_order,
        enable_images=enable_images,
        enable_total_record_count=enable_total_record_count,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    min_community_rating: Union[Unset, None, float] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    enable_images: Union[Unset, None, bool] = True,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Gets all artists from a given item, folder, or the entire library.

    Args:
        min_community_rating (Union[Unset, None, float]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        search_term (Union[Unset, None, str]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        studio_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        enable_images (Union[Unset, None, bool]):  Default: True.
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        min_community_rating=min_community_rating,
        start_index=start_index,
        limit=limit,
        search_term=search_term,
        parent_id=parent_id,
        fields=fields,
        exclude_item_types=exclude_item_types,
        include_item_types=include_item_types,
        filters=filters,
        is_favorite=is_favorite,
        media_types=media_types,
        genres=genres,
        genre_ids=genre_ids,
        official_ratings=official_ratings,
        tags=tags,
        years=years,
        enable_user_data=enable_user_data,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        person=person,
        person_ids=person_ids,
        person_types=person_types,
        studios=studios,
        studio_ids=studio_ids,
        user_id=user_id,
        name_starts_with_or_greater=name_starts_with_or_greater,
        name_starts_with=name_starts_with,
        name_less_than=name_less_than,
        sort_by=sort_by,
        sort_order=sort_order,
        enable_images=enable_images,
        enable_total_record_count=enable_total_record_count,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    min_community_rating: Union[Unset, None, float] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    search_term: Union[Unset, None, str] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    filters: Union[Unset, None, List[ItemFilter]] = UNSET,
    is_favorite: Union[Unset, None, bool] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    official_ratings: Union[Unset, None, List[str]] = UNSET,
    tags: Union[Unset, None, List[str]] = UNSET,
    years: Union[Unset, None, List[int]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    person: Union[Unset, None, str] = UNSET,
    person_ids: Union[Unset, None, List[str]] = UNSET,
    person_types: Union[Unset, None, List[str]] = UNSET,
    studios: Union[Unset, None, List[str]] = UNSET,
    studio_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    name_starts_with_or_greater: Union[Unset, None, str] = UNSET,
    name_starts_with: Union[Unset, None, str] = UNSET,
    name_less_than: Union[Unset, None, str] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    enable_images: Union[Unset, None, bool] = True,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Gets all artists from a given item, folder, or the entire library.

    Args:
        min_community_rating (Union[Unset, None, float]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        search_term (Union[Unset, None, str]):
        parent_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        filters (Union[Unset, None, List[ItemFilter]]):
        is_favorite (Union[Unset, None, bool]):
        media_types (Union[Unset, None, List[str]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        official_ratings (Union[Unset, None, List[str]]):
        tags (Union[Unset, None, List[str]]):
        years (Union[Unset, None, List[int]]):
        enable_user_data (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        person (Union[Unset, None, str]):
        person_ids (Union[Unset, None, List[str]]):
        person_types (Union[Unset, None, List[str]]):
        studios (Union[Unset, None, List[str]]):
        studio_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        name_starts_with_or_greater (Union[Unset, None, str]):
        name_starts_with (Union[Unset, None, str]):
        name_less_than (Union[Unset, None, str]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        enable_images (Union[Unset, None, bool]):  Default: True.
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return (
        await asyncio_detailed(
            client=client,
            min_community_rating=min_community_rating,
            start_index=start_index,
            limit=limit,
            search_term=search_term,
            parent_id=parent_id,
            fields=fields,
            exclude_item_types=exclude_item_types,
            include_item_types=include_item_types,
            filters=filters,
            is_favorite=is_favorite,
            media_types=media_types,
            genres=genres,
            genre_ids=genre_ids,
            official_ratings=official_ratings,
            tags=tags,
            years=years,
            enable_user_data=enable_user_data,
            image_type_limit=image_type_limit,
            enable_image_types=enable_image_types,
            person=person,
            person_ids=person_ids,
            person_types=person_types,
            studios=studios,
            studio_ids=studio_ids,
            user_id=user_id,
            name_starts_with_or_greater=name_starts_with_or_greater,
            name_starts_with=name_starts_with,
            name_less_than=name_less_than,
            sort_by=sort_by,
            sort_order=sort_order,
            enable_images=enable_images,
            enable_total_record_count=enable_total_record_count,
        )
    ).parsed
